Class: Aws::Chime::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Chime::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-chime/client.rb,
sig/client.rbs
Overview
An API client for Chime. To construct a client, you need to configure a :region and :credentials.
client = Aws::Chime::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociatePhoneNumberWithUserResponseSuccess, _AssociateSigninDelegateGroupsWithAccountResponseSuccess, _BatchCreateRoomMembershipResponseSuccess, _BatchDeletePhoneNumberResponseSuccess, _BatchSuspendUserResponseSuccess, _BatchUnsuspendUserResponseSuccess, _BatchUpdatePhoneNumberResponseSuccess, _BatchUpdateUserResponseSuccess, _CreateAccountResponseSuccess, _CreateBotResponseSuccess, _CreateMeetingDialOutResponseSuccess, _CreatePhoneNumberOrderResponseSuccess, _CreateRoomMembershipResponseSuccess, _CreateRoomResponseSuccess, _CreateUserResponseSuccess, _DeleteAccountResponseSuccess, _DisassociatePhoneNumberFromUserResponseSuccess, _DisassociateSigninDelegateGroupsFromAccountResponseSuccess, _GetAccountResponseSuccess, _GetAccountSettingsResponseSuccess, _GetBotResponseSuccess, _GetEventsConfigurationResponseSuccess, _GetGlobalSettingsResponseSuccess, _GetPhoneNumberOrderResponseSuccess, _GetPhoneNumberResponseSuccess, _GetPhoneNumberSettingsResponseSuccess, _GetRetentionSettingsResponseSuccess, _GetRoomResponseSuccess, _GetUserResponseSuccess, _GetUserSettingsResponseSuccess, _InviteUsersResponseSuccess, _ListAccountsResponseSuccess, _ListBotsResponseSuccess, _ListPhoneNumberOrdersResponseSuccess, _ListPhoneNumbersResponseSuccess, _ListRoomMembershipsResponseSuccess, _ListRoomsResponseSuccess, _ListSupportedPhoneNumberCountriesResponseSuccess, _ListUsersResponseSuccess, _LogoutUserResponseSuccess, _PutEventsConfigurationResponseSuccess, _PutRetentionSettingsResponseSuccess, _RedactConversationMessageResponseSuccess, _RedactRoomMessageResponseSuccess, _RegenerateSecurityTokenResponseSuccess, _ResetPersonalPINResponseSuccess, _RestorePhoneNumberResponseSuccess, _SearchAvailablePhoneNumbersResponseSuccess, _UpdateAccountResponseSuccess, _UpdateAccountSettingsResponseSuccess, _UpdateBotResponseSuccess, _UpdatePhoneNumberResponseSuccess, _UpdateRoomMembershipResponseSuccess, _UpdateRoomResponseSuccess, _UpdateUserResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_phone_number_with_user(params = {}) ⇒ Struct
Associates a phone number with the specified Amazon Chime user.
-
#associate_signin_delegate_groups_with_account(params = {}) ⇒ Struct
Associates the specified sign-in delegate groups with the specified Amazon Chime account.
-
#batch_create_room_membership(params = {}) ⇒ Types::BatchCreateRoomMembershipResponse
Adds up to 50 members to a chat room in an Amazon Chime Enterprise account.
-
#batch_delete_phone_number(params = {}) ⇒ Types::BatchDeletePhoneNumberResponse
Moves phone numbers into the Deletion queue.
-
#batch_suspend_user(params = {}) ⇒ Types::BatchSuspendUserResponse
Suspends up to 50 users from a
TeamorEnterpriseLWAAmazon Chime account. -
#batch_unsuspend_user(params = {}) ⇒ Types::BatchUnsuspendUserResponse
Removes the suspension from up to 50 previously suspended users for the specified Amazon Chime
EnterpriseLWAaccount. -
#batch_update_phone_number(params = {}) ⇒ Types::BatchUpdatePhoneNumberResponse
Updates phone number product types or calling names.
-
#batch_update_user(params = {}) ⇒ Types::BatchUpdateUserResponse
Updates user details within the UpdateUserRequestItem object for up to 20 users for the specified Amazon Chime account.
-
#create_account(params = {}) ⇒ Types::CreateAccountResponse
Creates an Amazon Chime account under the administrator's AWS account.
-
#create_bot(params = {}) ⇒ Types::CreateBotResponse
Creates a bot for an Amazon Chime Enterprise account.
-
#create_meeting_dial_out(params = {}) ⇒ Types::CreateMeetingDialOutResponse
Uses the join token and call metadata in a meeting request (From number, To number, and so forth) to initiate an outbound call to a public switched telephone network (PSTN) and join them into a Chime meeting.
-
#create_phone_number_order(params = {}) ⇒ Types::CreatePhoneNumberOrderResponse
Creates an order for phone numbers to be provisioned.
-
#create_room(params = {}) ⇒ Types::CreateRoomResponse
Creates a chat room for the specified Amazon Chime Enterprise account.
-
#create_room_membership(params = {}) ⇒ Types::CreateRoomMembershipResponse
Adds a member to a chat room in an Amazon Chime Enterprise account.
-
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a user under the specified Amazon Chime account.
-
#delete_account(params = {}) ⇒ Struct
Deletes the specified Amazon Chime account.
-
#delete_events_configuration(params = {}) ⇒ Struct
Deletes the events configuration that allows a bot to receive outgoing events.
-
#delete_phone_number(params = {}) ⇒ Struct
Moves the specified phone number into the Deletion queue.
-
#delete_room(params = {}) ⇒ Struct
Deletes a chat room in an Amazon Chime Enterprise account.
-
#delete_room_membership(params = {}) ⇒ Struct
Removes a member from a chat room in an Amazon Chime Enterprise account.
-
#disassociate_phone_number_from_user(params = {}) ⇒ Struct
Disassociates the primary provisioned phone number from the specified Amazon Chime user.
-
#disassociate_signin_delegate_groups_from_account(params = {}) ⇒ Struct
Disassociates the specified sign-in delegate groups from the specified Amazon Chime account.
-
#get_account(params = {}) ⇒ Types::GetAccountResponse
Retrieves details for the specified Amazon Chime account, such as account type and supported licenses.
-
#get_account_settings(params = {}) ⇒ Types::GetAccountSettingsResponse
Retrieves account settings for the specified Amazon Chime account ID, such as remote control and dialout settings.
-
#get_bot(params = {}) ⇒ Types::GetBotResponse
Retrieves details for the specified bot, such as bot email address, bot type, status, and display name.
-
#get_events_configuration(params = {}) ⇒ Types::GetEventsConfigurationResponse
Gets details for an events configuration that allows a bot to receive outgoing events, such as an HTTPS endpoint or Lambda function ARN.
-
#get_global_settings(params = {}) ⇒ Types::GetGlobalSettingsResponse
Retrieves global settings for the administrator's AWS account, such as Amazon Chime Business Calling and Amazon Chime Voice Connector settings.
-
#get_phone_number(params = {}) ⇒ Types::GetPhoneNumberResponse
Retrieves details for the specified phone number ID, such as associations, capabilities, and product type.
-
#get_phone_number_order(params = {}) ⇒ Types::GetPhoneNumberOrderResponse
Retrieves details for the specified phone number order, such as the order creation timestamp, phone numbers in E.164 format, product type, and order status.
-
#get_phone_number_settings(params = {}) ⇒ Types::GetPhoneNumberSettingsResponse
Retrieves the phone number settings for the administrator's AWS account, such as the default outbound calling name.
-
#get_retention_settings(params = {}) ⇒ Types::GetRetentionSettingsResponse
Gets the retention settings for the specified Amazon Chime Enterprise account.
-
#get_room(params = {}) ⇒ Types::GetRoomResponse
Retrieves room details, such as the room name, for a room in an Amazon Chime Enterprise account.
-
#get_user(params = {}) ⇒ Types::GetUserResponse
Retrieves details for the specified user ID, such as primary email address, license type,and personal meeting PIN.
-
#get_user_settings(params = {}) ⇒ Types::GetUserSettingsResponse
Retrieves settings for the specified user ID, such as any associated phone number settings.
-
#invite_users(params = {}) ⇒ Types::InviteUsersResponse
Sends email to a maximum of 50 users, inviting them to the specified Amazon Chime
Teamaccount. -
#list_accounts(params = {}) ⇒ Types::ListAccountsResponse
Lists the Amazon Chime accounts under the administrator's AWS account.
-
#list_bots(params = {}) ⇒ Types::ListBotsResponse
Lists the bots associated with the administrator's Amazon Chime Enterprise account ID.
-
#list_phone_number_orders(params = {}) ⇒ Types::ListPhoneNumberOrdersResponse
Lists the phone number orders for the administrator's Amazon Chime account.
-
#list_phone_numbers(params = {}) ⇒ Types::ListPhoneNumbersResponse
Lists the phone numbers for the specified Amazon Chime account, Amazon Chime user, Amazon Chime Voice Connector, or Amazon Chime Voice Connector group.
-
#list_room_memberships(params = {}) ⇒ Types::ListRoomMembershipsResponse
Lists the membership details for the specified room in an Amazon Chime Enterprise account, such as the members' IDs, email addresses, and names.
-
#list_rooms(params = {}) ⇒ Types::ListRoomsResponse
Lists the room details for the specified Amazon Chime Enterprise account.
-
#list_supported_phone_number_countries(params = {}) ⇒ Types::ListSupportedPhoneNumberCountriesResponse
Lists supported phone number countries.
-
#list_users(params = {}) ⇒ Types::ListUsersResponse
Lists the users that belong to the specified Amazon Chime account.
-
#logout_user(params = {}) ⇒ Struct
Logs out the specified user from all of the devices they are currently logged into.
-
#put_events_configuration(params = {}) ⇒ Types::PutEventsConfigurationResponse
Creates an events configuration that allows a bot to receive outgoing events sent by Amazon Chime.
-
#put_retention_settings(params = {}) ⇒ Types::PutRetentionSettingsResponse
Puts retention settings for the specified Amazon Chime Enterprise account.
-
#redact_conversation_message(params = {}) ⇒ Struct
Redacts the specified message from the specified Amazon Chime conversation.
-
#redact_room_message(params = {}) ⇒ Struct
Redacts the specified message from the specified Amazon Chime channel.
-
#regenerate_security_token(params = {}) ⇒ Types::RegenerateSecurityTokenResponse
Regenerates the security token for a bot.
-
#reset_personal_pin(params = {}) ⇒ Types::ResetPersonalPINResponse
Resets the personal meeting PIN for the specified user on an Amazon Chime account.
-
#restore_phone_number(params = {}) ⇒ Types::RestorePhoneNumberResponse
Moves a phone number from the Deletion queue back into the phone number Inventory.
-
#search_available_phone_numbers(params = {}) ⇒ Types::SearchAvailablePhoneNumbersResponse
Searches for phone numbers that can be ordered.
-
#update_account(params = {}) ⇒ Types::UpdateAccountResponse
Updates account details for the specified Amazon Chime account.
-
#update_account_settings(params = {}) ⇒ Struct
Updates the settings for the specified Amazon Chime account.
-
#update_bot(params = {}) ⇒ Types::UpdateBotResponse
Updates the status of the specified bot, such as starting or stopping the bot from running in your Amazon Chime Enterprise account.
-
#update_global_settings(params = {}) ⇒ Struct
Updates global settings for the administrator's AWS account, such as Amazon Chime Business Calling and Amazon Chime Voice Connector settings.
-
#update_phone_number(params = {}) ⇒ Types::UpdatePhoneNumberResponse
Updates phone number details, such as product type or calling name, for the specified phone number ID.
-
#update_phone_number_settings(params = {}) ⇒ Struct
Updates the phone number settings for the administrator's AWS account, such as the default outbound calling name.
-
#update_room(params = {}) ⇒ Types::UpdateRoomResponse
Updates room details, such as the room name, for a room in an Amazon Chime Enterprise account.
-
#update_room_membership(params = {}) ⇒ Types::UpdateRoomMembershipResponse
Updates room membership details, such as the member role, for a room in an Amazon Chime Enterprise account.
-
#update_user(params = {}) ⇒ Types::UpdateUserResponse
Updates user details for a specified user ID.
-
#update_user_settings(params = {}) ⇒ Struct
Updates the settings for the specified user, such as phone number settings.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-chime/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3142 3143 3144 |
# File 'lib/aws-sdk-chime/client.rb', line 3142 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3145 3146 3147 |
# File 'lib/aws-sdk-chime/client.rb', line 3145 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_phone_number_with_user(params = {}) ⇒ Struct
Associates a phone number with the specified Amazon Chime user.
85 |
# File 'sig/client.rbs', line 85
def associate_phone_number_with_user: (
|
#associate_signin_delegate_groups_with_account(params = {}) ⇒ Struct
Associates the specified sign-in delegate groups with the specified Amazon Chime account.
96 |
# File 'sig/client.rbs', line 96
def associate_signin_delegate_groups_with_account: (
|
#batch_create_room_membership(params = {}) ⇒ Types::BatchCreateRoomMembershipResponse
Adds up to 50 members to a chat room in an Amazon Chime Enterprise account. Members can be users or bots. The member role designates whether the member is a chat room administrator or a general chat room member.
111 |
# File 'sig/client.rbs', line 111
def batch_create_room_membership: (
|
#batch_delete_phone_number(params = {}) ⇒ Types::BatchDeletePhoneNumberResponse
Moves phone numbers into the Deletion queue. Phone numbers must be disassociated from any users or Amazon Chime Voice Connectors before they can be deleted.
Phone numbers remain in the Deletion queue for 7 days before they are deleted permanently.
128 |
# File 'sig/client.rbs', line 128
def batch_delete_phone_number: (
|
#batch_suspend_user(params = {}) ⇒ Types::BatchSuspendUserResponse
Suspends up to 50 users from a Team or EnterpriseLWA Amazon Chime
account. For more information about different account types, see
Managing Your Amazon Chime Accounts in the Amazon Chime
Administration Guide.
Users suspended from a Team account are disassociated from the
account,but they can continue to use Amazon Chime as free users. To
remove the suspension from suspended Team account users, invite them
to the Team account again. You can use the InviteUsers action to do
so.
Users suspended from an EnterpriseLWA account are immediately signed
out of Amazon Chime and can no longer sign in. To remove the
suspension from suspended EnterpriseLWA account users, use the
BatchUnsuspendUser action.
To sign out users without suspending them, use the LogoutUser action.
138 |
# File 'sig/client.rbs', line 138
def batch_suspend_user: (
|
#batch_unsuspend_user(params = {}) ⇒ Types::BatchUnsuspendUserResponse
Removes the suspension from up to 50 previously suspended users for
the specified Amazon Chime EnterpriseLWA account. Only users on
EnterpriseLWA accounts can be unsuspended using this action. For
more information about different account types, see Managing Your
Amazon Chime Accounts in the account types, in the Amazon Chime
Administration Guide.
Previously suspended users who are unsuspended using this action are
returned to Registered status. Users who are not previously
suspended are ignored.
149 |
# File 'sig/client.rbs', line 149
def batch_unsuspend_user: (
|
#batch_update_phone_number(params = {}) ⇒ Types::BatchUpdatePhoneNumberResponse
Updates phone number product types or calling names. You can update
one attribute at a time for each UpdatePhoneNumberRequestItem. For
example, you can update the product type or the calling name.
For toll-free numbers, you cannot use the Amazon Chime Business Calling product type. For numbers outside the U.S., you must use the Amazon Chime SIP Media Application Dial-In product type.
Updates to outbound calling names can take up to 72 hours to complete. Pending updates to outbound calling names must be complete before you can request another update.
160 |
# File 'sig/client.rbs', line 160
def batch_update_phone_number: (
|
#batch_update_user(params = {}) ⇒ Types::BatchUpdateUserResponse
Updates user details within the UpdateUserRequestItem object for up to
20 users for the specified Amazon Chime account. Currently, only
LicenseType updates are supported for this action.
176 |
# File 'sig/client.rbs', line 176
def batch_update_user: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3115 3116 3117 3118 3119 3120 3121 3122 3123 3124 3125 3126 3127 3128 3129 3130 3131 |
# File 'lib/aws-sdk-chime/client.rb', line 3115 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Chime') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-chime' context[:gem_version] = '1.120.0' Seahorse::Client::Request.new(handlers, context) end |
#create_account(params = {}) ⇒ Types::CreateAccountResponse
Creates an Amazon Chime account under the administrator's AWS
account. Only Team account types are currently supported for this
action. For more information about different account types, see
Managing Your Amazon Chime Accounts in the Amazon Chime
Administration Guide.
197 |
# File 'sig/client.rbs', line 197
def create_account: (
|
#create_bot(params = {}) ⇒ Types::CreateBotResponse
Creates a bot for an Amazon Chime Enterprise account.
207 |
# File 'sig/client.rbs', line 207
def create_bot: (
|
#create_meeting_dial_out(params = {}) ⇒ Types::CreateMeetingDialOutResponse
Uses the join token and call metadata in a meeting request (From number, To number, and so forth) to initiate an outbound call to a public switched telephone network (PSTN) and join them into a Chime meeting. Also ensures that the From number belongs to the customer.
To play welcome audio or implement an interactive voice response
(IVR), use the CreateSipMediaApplicationCall action with the
corresponding SIP media application ID.
This API is not available in a dedicated namespace.
219 |
# File 'sig/client.rbs', line 219
def create_meeting_dial_out: (
|
#create_phone_number_order(params = {}) ⇒ Types::CreatePhoneNumberOrderResponse
Creates an order for phone numbers to be provisioned. For toll-free numbers, you cannot use the Amazon Chime Business Calling product type. For numbers outside the U.S., you must use the Amazon Chime SIP Media Application Dial-In product type.
232 |
# File 'sig/client.rbs', line 232
def create_phone_number_order: (
|
#create_room(params = {}) ⇒ Types::CreateRoomResponse
Creates a chat room for the specified Amazon Chime Enterprise account.
243 |
# File 'sig/client.rbs', line 243
def create_room: (
|
#create_room_membership(params = {}) ⇒ Types::CreateRoomMembershipResponse
Adds a member to a chat room in an Amazon Chime Enterprise account. A member can be either a user or a bot. The member role designates whether the member is a chat room administrator or a general chat room member.
255 |
# File 'sig/client.rbs', line 255
def create_room_membership: (
|
#create_user(params = {}) ⇒ Types::CreateUserResponse
Creates a user under the specified Amazon Chime account.
268 |
# File 'sig/client.rbs', line 268
def create_user: (
|
#delete_account(params = {}) ⇒ Struct
Deletes the specified Amazon Chime account. You must suspend all users
before deleting Team account. You can use the BatchSuspendUser
action to dodo.
For EnterpriseLWA and EnterpriseAD accounts, you must release the
claimed domains for your Amazon Chime account before deletion. As soon
as you release the domain, all users under that account are suspended.
Deleted accounts appear in your Disabled accounts list for 90 days.
To restore deleted account from your Disabled accounts list, you
must contact AWS Support.
After 90 days, deleted accounts are permanently removed from your
Disabled accounts list.
280 |
# File 'sig/client.rbs', line 280
def delete_account: (
|
#delete_events_configuration(params = {}) ⇒ Struct
Deletes the events configuration that allows a bot to receive outgoing events.
286 |
# File 'sig/client.rbs', line 286
def delete_events_configuration: (
|
#delete_phone_number(params = {}) ⇒ Struct
Moves the specified phone number into the Deletion queue. A phone number must be disassociated from any users or Amazon Chime Voice Connectors before it can be deleted.
Deleted phone numbers remain in the Deletion queue for 7 days before they are deleted permanently.
293 |
# File 'sig/client.rbs', line 293
def delete_phone_number: (
|
#delete_room(params = {}) ⇒ Struct
Deletes a chat room in an Amazon Chime Enterprise account.
299 |
# File 'sig/client.rbs', line 299
def delete_room: (
|
#delete_room_membership(params = {}) ⇒ Struct
Removes a member from a chat room in an Amazon Chime Enterprise account.
306 |
# File 'sig/client.rbs', line 306
def delete_room_membership: (
|
#disassociate_phone_number_from_user(params = {}) ⇒ Struct
Disassociates the primary provisioned phone number from the specified Amazon Chime user.
317 |
# File 'sig/client.rbs', line 317
def disassociate_phone_number_from_user: (
|
#disassociate_signin_delegate_groups_from_account(params = {}) ⇒ Struct
Disassociates the specified sign-in delegate groups from the specified Amazon Chime account.
327 |
# File 'sig/client.rbs', line 327
def disassociate_signin_delegate_groups_from_account: (
|
#get_account(params = {}) ⇒ Types::GetAccountResponse
Retrieves details for the specified Amazon Chime account, such as account type and supported licenses.
338 |
# File 'sig/client.rbs', line 338
def get_account: (
|
#get_account_settings(params = {}) ⇒ Types::GetAccountSettingsResponse
Retrieves account settings for the specified Amazon Chime account ID, such as remote control and dialout settings. For more information about these settings, see Use the Policies Page in the Amazon Chime Administration Guide.
348 |
# File 'sig/client.rbs', line 348
def get_account_settings: (
|
#get_bot(params = {}) ⇒ Types::GetBotResponse
Retrieves details for the specified bot, such as bot email address, bot type, status, and display name.
358 |
# File 'sig/client.rbs', line 358
def get_bot: (
|
#get_events_configuration(params = {}) ⇒ Types::GetEventsConfigurationResponse
Gets details for an events configuration that allows a bot to receive outgoing events, such as an HTTPS endpoint or Lambda function ARN.
369 |
# File 'sig/client.rbs', line 369
def get_events_configuration: (
|
#get_global_settings(params = {}) ⇒ Types::GetGlobalSettingsResponse
Retrieves global settings for the administrator's AWS account, such as Amazon Chime Business Calling and Amazon Chime Voice Connector settings.
381 382 |
# File 'sig/client.rbs', line 381
def get_global_settings: () -> _GetGlobalSettingsResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetGlobalSettingsResponseSuccess
|
#get_phone_number(params = {}) ⇒ Types::GetPhoneNumberResponse
Retrieves details for the specified phone number ID, such as associations, capabilities, and product type.
389 |
# File 'sig/client.rbs', line 389
def get_phone_number: (
|
#get_phone_number_order(params = {}) ⇒ Types::GetPhoneNumberOrderResponse
Retrieves details for the specified phone number order, such as the order creation timestamp, phone numbers in E.164 format, product type, and order status.
399 |
# File 'sig/client.rbs', line 399
def get_phone_number_order: (
|
#get_phone_number_settings(params = {}) ⇒ Types::GetPhoneNumberSettingsResponse
Retrieves the phone number settings for the administrator's AWS account, such as the default outbound calling name.
410 411 |
# File 'sig/client.rbs', line 410
def get_phone_number_settings: () -> _GetPhoneNumberSettingsResponseSuccess
| (?Hash[Symbol, untyped] params, ?Hash[Symbol, untyped] options) -> _GetPhoneNumberSettingsResponseSuccess
|
#get_retention_settings(params = {}) ⇒ Types::GetRetentionSettingsResponse
Gets the retention settings for the specified Amazon Chime Enterprise account. For more information about retention settings, see Managing Chat Retention Policies in the Amazon Chime Administration Guide.
419 |
# File 'sig/client.rbs', line 419
def get_retention_settings: (
|
#get_room(params = {}) ⇒ Types::GetRoomResponse
Retrieves room details, such as the room name, for a room in an Amazon Chime Enterprise account.
429 |
# File 'sig/client.rbs', line 429
def get_room: (
|
#get_user(params = {}) ⇒ Types::GetUserResponse
Retrieves details for the specified user ID, such as primary email address, license type,and personal meeting PIN.
To retrieve user details with an email address instead of a user ID, use the ListUsers action, and then filter by email address.
440 |
# File 'sig/client.rbs', line 440
def get_user: (
|
#get_user_settings(params = {}) ⇒ Types::GetUserSettingsResponse
Retrieves settings for the specified user ID, such as any associated phone number settings.
451 |
# File 'sig/client.rbs', line 451
def get_user_settings: (
|
#invite_users(params = {}) ⇒ Types::InviteUsersResponse
Sends email to a maximum of 50 users, inviting them to the specified
Amazon Chime Team account. Only Team account types are currently
supported for this action.
462 |
# File 'sig/client.rbs', line 462
def invite_users: (
|
#list_accounts(params = {}) ⇒ Types::ListAccountsResponse
Lists the Amazon Chime accounts under the administrator's AWS account. You can filter accounts by account name prefix. To find out which Amazon Chime account a user belongs to, you can filter by the user's email address, which returns one account result.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
475 |
# File 'sig/client.rbs', line 475
def list_accounts: (
|
#list_bots(params = {}) ⇒ Types::ListBotsResponse
Lists the bots associated with the administrator's Amazon Chime Enterprise account ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
489 |
# File 'sig/client.rbs', line 489
def list_bots: (
|
#list_phone_number_orders(params = {}) ⇒ Types::ListPhoneNumberOrdersResponse
Lists the phone number orders for the administrator's Amazon Chime account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
502 |
# File 'sig/client.rbs', line 502
def list_phone_number_orders: (
|
#list_phone_numbers(params = {}) ⇒ Types::ListPhoneNumbersResponse
Lists the phone numbers for the specified Amazon Chime account, Amazon Chime user, Amazon Chime Voice Connector, or Amazon Chime Voice Connector group.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
514 |
# File 'sig/client.rbs', line 514
def list_phone_numbers: (
|
#list_room_memberships(params = {}) ⇒ Types::ListRoomMembershipsResponse
Lists the membership details for the specified room in an Amazon Chime Enterprise account, such as the members' IDs, email addresses, and names.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
530 |
# File 'sig/client.rbs', line 530
def list_room_memberships: (
|
#list_rooms(params = {}) ⇒ Types::ListRoomsResponse
Lists the room details for the specified Amazon Chime Enterprise account. Optionally, filter the results by a member ID (user ID or bot ID) to see a list of rooms that the member belongs to.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
544 |
# File 'sig/client.rbs', line 544
def list_rooms: (
|
#list_supported_phone_number_countries(params = {}) ⇒ Types::ListSupportedPhoneNumberCountriesResponse
Lists supported phone number countries.
557 |
# File 'sig/client.rbs', line 557
def list_supported_phone_number_countries: (
|
#list_users(params = {}) ⇒ Types::ListUsersResponse
Lists the users that belong to the specified Amazon Chime account. You can specify an email address to list only the user that the email address belongs to.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
568 |
# File 'sig/client.rbs', line 568
def list_users: (
|
#logout_user(params = {}) ⇒ Struct
Logs out the specified user from all of the devices they are currently logged into.
581 |
# File 'sig/client.rbs', line 581
def logout_user: (
|
#put_events_configuration(params = {}) ⇒ Types::PutEventsConfigurationResponse
Creates an events configuration that allows a bot to receive outgoing events sent by Amazon Chime. Choose either an HTTPS endpoint or a Lambda function ARN. For more information, see Bot.
592 |
# File 'sig/client.rbs', line 592
def put_events_configuration: (
|
#put_retention_settings(params = {}) ⇒ Types::PutRetentionSettingsResponse
Puts retention settings for the specified Amazon Chime Enterprise account. We recommend using AWS CloudTrail to monitor usage of this API for your account. For more information, see Logging Amazon Chime API Calls with AWS CloudTrail in the Amazon Chime Administration Guide.
To turn off existing retention settings, remove the number of days from the corresponding RetentionDays field in the RetentionSettings object. For more information about retention settings, see Managing Chat Retention Policies in the Amazon Chime Administration Guide.
606 |
# File 'sig/client.rbs', line 606
def put_retention_settings: (
|
#redact_conversation_message(params = {}) ⇒ Struct
Redacts the specified message from the specified Amazon Chime conversation.
623 |
# File 'sig/client.rbs', line 623
def redact_conversation_message: (
|
#redact_room_message(params = {}) ⇒ Struct
Redacts the specified message from the specified Amazon Chime channel.
634 |
# File 'sig/client.rbs', line 634
def redact_room_message: (
|
#regenerate_security_token(params = {}) ⇒ Types::RegenerateSecurityTokenResponse
Regenerates the security token for a bot.
646 |
# File 'sig/client.rbs', line 646
def regenerate_security_token: (
|
#reset_personal_pin(params = {}) ⇒ Types::ResetPersonalPINResponse
Resets the personal meeting PIN for the specified user on an Amazon Chime account. Returns the User object with the updated personal meeting PIN.
657 |
# File 'sig/client.rbs', line 657
def reset_personal_pin: (
|
#restore_phone_number(params = {}) ⇒ Types::RestorePhoneNumberResponse
Moves a phone number from the Deletion queue back into the phone number Inventory.
668 |
# File 'sig/client.rbs', line 668
def restore_phone_number: (
|
#search_available_phone_numbers(params = {}) ⇒ Types::SearchAvailablePhoneNumbersResponse
Searches for phone numbers that can be ordered. For US numbers,
provide at least one of the following search filters: AreaCode,
City, State, or TollFreePrefix. If you provide City, you must
also provide State. Numbers outside the US only support the
PhoneNumberType filter, which you must use.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
679 |
# File 'sig/client.rbs', line 679
def search_available_phone_numbers: (
|
#update_account(params = {}) ⇒ Types::UpdateAccountResponse
Updates account details for the specified Amazon Chime account. Currently, only account name and default license updates are supported for this action.
696 |
# File 'sig/client.rbs', line 696
def update_account: (
|
#update_account_settings(params = {}) ⇒ Struct
Updates the settings for the specified Amazon Chime account. You can update settings for remote control of shared screens, or for the dial-out option. For more information about these settings, see Use the Policies Page in the Amazon Chime Administration Guide.
707 |
# File 'sig/client.rbs', line 707
def update_account_settings: (
|
#update_bot(params = {}) ⇒ Types::UpdateBotResponse
Updates the status of the specified bot, such as starting or stopping the bot from running in your Amazon Chime Enterprise account.
721 |
# File 'sig/client.rbs', line 721
def update_bot: (
|
#update_global_settings(params = {}) ⇒ Struct
Updates global settings for the administrator's AWS account, such as Amazon Chime Business Calling and Amazon Chime Voice Connector settings.
729 |
# File 'sig/client.rbs', line 729
def update_global_settings: (
|
#update_phone_number(params = {}) ⇒ Types::UpdatePhoneNumberResponse
Updates phone number details, such as product type or calling name, for the specified phone number ID. You can update one phone number detail at a time. For example, you can update either the product type or the calling name in one action.
For toll-free numbers, you cannot use the Amazon Chime Business Calling product type. For numbers outside the U.S., you must use the Amazon Chime SIP Media Application Dial-In product type.
Updates to outbound calling names can take 72 hours to complete. Pending updates to outbound calling names must be complete before you can request another update.
744 |
# File 'sig/client.rbs', line 744
def update_phone_number: (
|
#update_phone_number_settings(params = {}) ⇒ Struct
Updates the phone number settings for the administrator's AWS account, such as the default outbound calling name. You can update the default outbound calling name once every seven days. Outbound calling names can take up to 72 hours to update.
752 |
# File 'sig/client.rbs', line 752
def update_phone_number_settings: (
|
#update_room(params = {}) ⇒ Types::UpdateRoomResponse
Updates room details, such as the room name, for a room in an Amazon Chime Enterprise account.
762 |
# File 'sig/client.rbs', line 762
def update_room: (
|
#update_room_membership(params = {}) ⇒ Types::UpdateRoomMembershipResponse
Updates room membership details, such as the member role, for a room in an Amazon Chime Enterprise account. The member role designates whether the member is a chat room administrator or a general chat room member. The member role can be updated only for user IDs.
774 |
# File 'sig/client.rbs', line 774
def update_room_membership: (
|
#update_user(params = {}) ⇒ Types::UpdateUserResponse
Updates user details for a specified user ID. Currently, only
LicenseType updates are supported for this action.
787 |
# File 'sig/client.rbs', line 787
def update_user: (
|
#update_user_settings(params = {}) ⇒ Struct
Updates the settings for the specified user, such as phone number settings.
800 |
# File 'sig/client.rbs', line 800
def update_user_settings: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3135 3136 3137 |
# File 'lib/aws-sdk-chime/client.rb', line 3135 def waiter_names [] end |