Class: Aws::Chime::Types::BatchCreateChannelMembershipRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Chime::Types::BatchCreateChannelMembershipRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_arn ⇒ String
The ARN of the channel to which you’re adding users.
-
#chime_bearer ⇒ String
The
AppInstanceUserArnof the user that makes the API call. -
#member_arns ⇒ Array<String>
The ARNs of the members you want to add to the channel.
-
#type ⇒ String
The membership type of a user,
DEFAULTorHIDDEN.
Instance Attribute Details
#channel_arn ⇒ String
The ARN of the channel to which you’re adding users.
738 739 740 741 742 743 744 745 |
# File 'lib/aws-sdk-chime/types.rb', line 738 class BatchCreateChannelMembershipRequest < Struct.new( :channel_arn, :type, :member_arns, :chime_bearer) SENSITIVE = [] include Aws::Structure end |
#chime_bearer ⇒ String
The AppInstanceUserArn of the user that makes the API call.
738 739 740 741 742 743 744 745 |
# File 'lib/aws-sdk-chime/types.rb', line 738 class BatchCreateChannelMembershipRequest < Struct.new( :channel_arn, :type, :member_arns, :chime_bearer) SENSITIVE = [] include Aws::Structure end |
#member_arns ⇒ Array<String>
The ARNs of the members you want to add to the channel.
738 739 740 741 742 743 744 745 |
# File 'lib/aws-sdk-chime/types.rb', line 738 class BatchCreateChannelMembershipRequest < Struct.new( :channel_arn, :type, :member_arns, :chime_bearer) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The membership type of a user, DEFAULT or HIDDEN. Default members are always returned as part of ListChannelMemberships. Hidden members are only returned if the type filter in ListChannelMemberships equals HIDDEN. Otherwise hidden members are not returned. This is only supported by moderators.
738 739 740 741 742 743 744 745 |
# File 'lib/aws-sdk-chime/types.rb', line 738 class BatchCreateChannelMembershipRequest < Struct.new( :channel_arn, :type, :member_arns, :chime_bearer) SENSITIVE = [] include Aws::Structure end |