Class: Aws::Chime::Types::CreateChannelMembershipRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Chime::Types::CreateChannelMembershipRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_arn ⇒ String
The ARN of the channel to which you’re adding users.
-
#chime_bearer ⇒ String
The
AppInstanceUserArnof the user that makes the API call. -
#member_arn ⇒ String
The ARN of the member you want to add to the channel.
-
#type ⇒ String
The membership type of a user,
DEFAULTorHIDDEN.
Instance Attribute Details
#channel_arn ⇒ String
The ARN of the channel to which you’re adding users.
1865 1866 1867 1868 1869 1870 1871 1872 |
# File 'lib/aws-sdk-chime/types.rb', line 1865 class CreateChannelMembershipRequest < Struct.new( :channel_arn, :member_arn, :type, :chime_bearer) SENSITIVE = [] include Aws::Structure end |
#chime_bearer ⇒ String
The AppInstanceUserArn of the user that makes the API call.
1865 1866 1867 1868 1869 1870 1871 1872 |
# File 'lib/aws-sdk-chime/types.rb', line 1865 class CreateChannelMembershipRequest < Struct.new( :channel_arn, :member_arn, :type, :chime_bearer) SENSITIVE = [] include Aws::Structure end |
#member_arn ⇒ String
The ARN of the member you want to add to the channel.
1865 1866 1867 1868 1869 1870 1871 1872 |
# File 'lib/aws-sdk-chime/types.rb', line 1865 class CreateChannelMembershipRequest < Struct.new( :channel_arn, :member_arn, :type, :chime_bearer) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The membership type of a user, DEFAULT or HIDDEN. Default members are always returned as part of ListChannelMemberships. Hidden members are only returned if the type filter in ListChannelMemberships equals HIDDEN. Otherwise hidden members are not returned. This is only supported by moderators.
1865 1866 1867 1868 1869 1870 1871 1872 |
# File 'lib/aws-sdk-chime/types.rb', line 1865 class CreateChannelMembershipRequest < Struct.new( :channel_arn, :member_arn, :type, :chime_bearer) SENSITIVE = [] include Aws::Structure end |