Class: Aws::Chime::Types::CreateSipRuleRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Chime::Types::CreateSipRuleRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#disabled ⇒ Boolean
Enables or disables a rule.
-
#name ⇒ String
The name of the SIP rule.
-
#target_applications ⇒ Array<Types::SipRuleTargetApplication>
List of SIP media applications with priority and AWS Region.
-
#trigger_type ⇒ String
The type of trigger assigned to the SIP rule in
TriggerValue, currentlyRequestUriHostnameorToPhoneNumber. -
#trigger_value ⇒ String
If
TriggerTypeisRequestUriHostname, the value can be the outbound host name of an Amazon Chime Voice Connector.
Instance Attribute Details
#disabled ⇒ Boolean
Enables or disables a rule. You must disable rules before you can delete them.
2512 2513 2514 2515 2516 2517 2518 2519 2520 |
# File 'lib/aws-sdk-chime/types.rb', line 2512 class CreateSipRuleRequest < Struct.new( :name, :trigger_type, :trigger_value, :disabled, :target_applications) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the SIP rule.
2512 2513 2514 2515 2516 2517 2518 2519 2520 |
# File 'lib/aws-sdk-chime/types.rb', line 2512 class CreateSipRuleRequest < Struct.new( :name, :trigger_type, :trigger_value, :disabled, :target_applications) SENSITIVE = [] include Aws::Structure end |
#target_applications ⇒ Array<Types::SipRuleTargetApplication>
List of SIP media applications with priority and AWS Region. Only one SIP application per AWS Region can be used.
2512 2513 2514 2515 2516 2517 2518 2519 2520 |
# File 'lib/aws-sdk-chime/types.rb', line 2512 class CreateSipRuleRequest < Struct.new( :name, :trigger_type, :trigger_value, :disabled, :target_applications) SENSITIVE = [] include Aws::Structure end |
#trigger_type ⇒ String
The type of trigger assigned to the SIP rule in TriggerValue, currently RequestUriHostname or ToPhoneNumber.
2512 2513 2514 2515 2516 2517 2518 2519 2520 |
# File 'lib/aws-sdk-chime/types.rb', line 2512 class CreateSipRuleRequest < Struct.new( :name, :trigger_type, :trigger_value, :disabled, :target_applications) SENSITIVE = [] include Aws::Structure end |
#trigger_value ⇒ String
If TriggerType is RequestUriHostname, the value can be the outbound host name of an Amazon Chime Voice Connector. If TriggerType is ToPhoneNumber, the value can be a customer-owned phone number in the E164 format. The SipMediaApplication specified in the SipRule is triggered if the request URI in an incoming SIP request matches the RequestUriHostname, or if the To header in the incoming SIP request matches the ToPhoneNumber value.
2512 2513 2514 2515 2516 2517 2518 2519 2520 |
# File 'lib/aws-sdk-chime/types.rb', line 2512 class CreateSipRuleRequest < Struct.new( :name, :trigger_type, :trigger_value, :disabled, :target_applications) SENSITIVE = [] include Aws::Structure end |