Class: Aws::Chime::Types::ListRoomMembershipsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Chime::Types::ListRoomMembershipsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chime/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token to use to retrieve the next page of results.
-
#room_memberships ⇒ Array<Types::RoomMembership>
The room membership details.
Instance Attribute Details
#next_token ⇒ String
The token to use to retrieve the next page of results.
1490 1491 1492 1493 1494 1495 |
# File 'lib/aws-sdk-chime/types.rb', line 1490 class ListRoomMembershipsResponse < Struct.new( :room_memberships, :next_token) SENSITIVE = [] include Aws::Structure end |
#room_memberships ⇒ Array<Types::RoomMembership>
The room membership details.
1490 1491 1492 1493 1494 1495 |
# File 'lib/aws-sdk-chime/types.rb', line 1490 class ListRoomMembershipsResponse < Struct.new( :room_memberships, :next_token) SENSITIVE = [] include Aws::Structure end |